@@ -6,7 +6,7 @@
 #include "cmdsetvisibility.h"
 
 // app includes
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 
