@@ -6,12 +6,12 @@
 #include "cmdbasewidgetcommand.h"
 
 // app includes
-#include "association.h"
+#include "umlassociation.h"
 #include "associationwidget.h"
-#include "folder.h"
+#include "umlfolder.h"
 #include "messagewidget.h"
 #include "model_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
