@@ -7,15 +7,15 @@
 
 #include "aswriter.h"
 
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for logWarn
+#include "umlapp.h"  // Only needed for logWarn
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 static const char *reserved_words[] = {
@@ -451,7 +451,7 @@ static const char *reserved_words[] = {
     "_xscale",
     "_y",
     "_ymouse",
-    0
+    nullptr
 };
 
 /**
@@ -486,14 +486,14 @@ void ASWriter::writeClass(UMLClassifier *c)
     fileName = findFileName(c, QStringLiteral(".as"));
     if (fileName.isEmpty())
     {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
     QFile fileas;
     if (!openFile(fileas, fileName))
     {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
     QTextStream as(&fileas);
@@ -507,15 +507,15 @@ void ASWriter::writeClass(UMLClassifier *c)
     str = getHeadingFile(QStringLiteral(".as"));
     if (!str.isEmpty())
     {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName + QStringLiteral(".as"));
-        str.replace(QRegExp(QStringLiteral("%filepath%")), fileas.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName + QStringLiteral(".as"));
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), fileas.fileName());
         as << str << m_endl;
     }
 
     //write includes
     UMLPackageList includes;
     findObjectsRelated(c, includes);
-    foreach (UMLPackage* conc, includes) {
+    for (UMLPackage* conc: includes) {
         QString headerName = findFileName(conc, QStringLiteral(".as"));
         if (!headerName.isEmpty())
         {
@@ -551,7 +551,7 @@ void ASWriter::writeClass(UMLClassifier *c)
     as << "}" << m_endl;
     as << m_endl;
 
-    foreach(UMLClassifier* obj, superclasses) {
+    for (UMLClassifier* obj: superclasses) {
         as << classname << ".prototype = new " << cleanName(obj->name()) << " ();" << m_endl;
     }
 
@@ -570,7 +570,7 @@ void ASWriter::writeClass(UMLClassifier *c)
         as << " */" << m_endl;
         as << classname << ".prototype._init = function ()" << m_endl;
         as << "{" << m_endl;
-        foreach (UMLAttribute* at, atl) {
+        for (UMLAttribute* at: atl) {
             if (forceDoc() || !at->doc().isEmpty())
             {
                 as << m_indentation << "/**" << m_endl
@@ -606,15 +606,15 @@ void ASWriter::writeClass(UMLClassifier *c)
 
     if (isClass) {
         UMLAttributeList atl = c->getAttributeList();
-        foreach (UMLAttribute* at, atl) {
+        for (UMLAttribute* at: atl) {
           if (at->visibility() == Uml::Visibility::Protected) {
                 as << m_indentation << "ASSetPropFlags (this, \"" << cleanName(at->name()) << "\", 1);" << m_endl;
           }
         }
     }
 
-    UMLOperationList opList(c->getOpList());
-    foreach (UMLOperation* op, opList) {
+    UMLOperationList opList(c->getOperationsList());
+    for (UMLOperation* op: opList) {
         if (op->visibility() == Uml::Visibility::Protected) {
             as << m_indentation << "ASSetPropFlags (this, \"" << cleanName(op->name()) << "\", 1);" << m_endl;
         }
@@ -623,14 +623,14 @@ void ASWriter::writeClass(UMLClassifier *c)
     as << m_indentation << "/**Private: */" << m_endl;
     if (isClass) {
         UMLAttributeList atl = c->getAttributeList();
-        foreach (UMLAttribute* at,  atl) {
+        for (UMLAttribute* at:  atl) {
             if (at->visibility() == Uml::Visibility::Private) {
                 as << m_indentation << "ASSetPropFlags (this, \"" << cleanName(at->name()) << "\", 7);" << m_endl;
             }
         }
     }
 
-    foreach (UMLOperation* op, opList) {
+    for (UMLOperation* op: opList) {
         if (op->visibility() == Uml::Visibility::Protected) {
             as << m_indentation << "ASSetPropFlags (this, \"" << cleanName(op->name()) << "\", 7);" << m_endl;
         }
@@ -640,7 +640,7 @@ void ASWriter::writeClass(UMLClassifier *c)
     as << m_endl;
 
     //operations
-    UMLOperationList ops(c->getOpList());
+    UMLOperationList ops(c->getOperationsList());
     writeOperations(classname, &ops, as);
 
     as << m_endl;
@@ -649,8 +649,8 @@ void ASWriter::writeClass(UMLClassifier *c)
 
     //close files and notfiy we are done
     fileas.close();
-    emit codeGenerated(c, true);
-    emit showGeneratedFile(fileas.fileName());
+    Q_EMIT codeGenerated(c, true);
+    Q_EMIT showGeneratedFile(fileas.fileName());
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
@@ -665,7 +665,7 @@ void ASWriter::writeClass(UMLClassifier *c)
  */
 void ASWriter::writeAssociation(QString& classname, UMLAssociationList& assocList, QTextStream &as)
 {
-    foreach (UMLAssociation *a, assocList)
+    for (UMLAssociation *a: assocList)
     {
         // association side
         Uml::RoleType::Enum role = a->getObject(Uml::RoleType::A)->name() == classname ? Uml::RoleType::B : Uml::RoleType::A;
@@ -723,11 +723,11 @@ void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
 {
     UMLAttributeList atl;
 
-    foreach (UMLOperation* op, *opList) {
-        atl = op -> getParmList();
+    for (UMLOperation* op: *opList) {
+        atl = op -> getParameterList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->doc().isEmpty();
-        foreach (UMLAttribute* at,  atl) {
+        for (UMLAttribute* at:  atl) {
             writeDoc |= !at->doc().isEmpty();
         }
 
@@ -735,7 +735,7 @@ void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
         {
             as << "/**" << m_endl << formatDoc(op->doc(), QStringLiteral(" * "));
 
-            foreach (UMLAttribute* at,  atl) {
+            for (UMLAttribute* at:  atl) {
                 if (forceDoc() || !at->doc().isEmpty()) {
                     as << " * @param " << cleanName(at->name()) << m_endl;
                     as << formatDoc(at->doc(), QStringLiteral("    *      "));
