@@ -8,13 +8,13 @@
 #include "javacodeclassfielddeclarationblock.h"
 
 #include "codegenerator.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "javacodeclassfield.h"
 #include "javaclassifiercodedocument.h"
 #include "javacodegenerationpolicy.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 
 /**
  * Constructor.
