@@ -11,7 +11,7 @@
 // local includes
 #include "rubyclassifiercodedocument.h"
 #include "rubycodegenerationpolicy.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // qt includes
 #include <QRegularExpression>
