@@ -7,14 +7,13 @@
 
 #include "xmlschemawriter.h"
 
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umldoc.h"
-#include "uml.h"  // Only needed for log{Warn,Error}
+#include "umlapp.h"  // Only needed for log{Warn,Error}
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QFile>
 #include <QRegularExpression>
