@@ -21,7 +21,7 @@ class CodeGenSelectPage : public QWizardPage, private Ui::CodeGenSelectPage
 {
     Q_OBJECT
 public:
-    explicit CodeGenSelectPage(QWidget * parent = 0);
+    explicit CodeGenSelectPage(QWidget  *parent = nullptr);
     ~CodeGenSelectPage();
     void setClassifierList(UMLClassifierList *classList);
     bool isComplete() const;
@@ -30,7 +30,7 @@ public:
 private:
     static void moveSelectedItems(QListWidget* fromList, QListWidget* toList);
 
-protected slots:
+protected Q_SLOTS:
     void selectClass();
     void deselectClass();
 
