@@ -11,7 +11,7 @@
 #define DBG_SRC QStringLiteral("NativeImportBase")
 #include "debug_utils.h"
 #include "import_utils.h"
-#include "uml.h"  // only needed for log{Warn,Error}
+#include "umlapp.h"  // only needed for log{Warn,Error}
 
 // kde includes
 #include <KLocalizedString>
