@@ -8,13 +8,12 @@
 // local includes
 #include "codeimpselectpage.h"
 #include "codeimpstatuspage.h"
-#include "classifier.h"
+#include "umlclassifier.h"
 #include "icon_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QFileInfo>
