@@ -15,10 +15,10 @@
 #include "componentwidget.h"
 #include "constraintlistpage.h"
 #include "debug_utils.h"
-#include "entity.h"
+#include "umlentity.h"
 #include "objectwidget.h"
 #include "packagecontentspage.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlview.h"
