@@ -8,7 +8,7 @@
 
 // local includes
 #include "associationwidget.h"
-#include "association.h"
+#include "umlassociation.h"
 #include "assocrules.h"
 #include "debug_utils.h"
 #include "dialog_utils.h"
@@ -16,13 +16,12 @@
 #include "objectwidget.h"
 #include "umldoc.h"
 #include "umlobject.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <kcombobox.h>
 #include <QLineEdit>
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <QTextEdit>
 
 // qt includes
