@@ -7,11 +7,11 @@
 #include "selectoperationdialog.h"
 
 // local includes
-#include "attribute.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "linkwidget.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "umlclassifierlistitemlist.h"
 #include "umlscene.h"
 #include "umlview.h"
@@ -218,7 +218,7 @@ bool SelectOperationDialog::setClassOp(const QString &op)
 void SelectOperationDialog::setupOperationsList()
 {
     m_pOpCB->clear();
-    UMLOperationList list = m_classifier->getOpList(true);
+    UMLOperationList list = m_classifier->getOperationsList(true);
     if (list.count() > 0)
         m_pOpCB->insertItem(0, QString());
     std::sort(list.begin(), list.end(), caseInsensitiveLessThan);
