@@ -11,7 +11,7 @@
 #include "diagrampropertiespage.h"
 #include "debug_utils.h"
 #include "icon_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
@@ -20,7 +20,6 @@
 // kde includes
 #include <kfontchooser.h>
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QFrame>
