@@ -5,9 +5,9 @@
 
 #include "defaultvaluewidget.h"
 
-#include "enum.h"
-#include "datatype.h"
-#include "uml.h"
+#include "umlenum.h"
+#include "umldatatype.h"
+#include "umlapp.h"
 #include "umldoc.h"
 
 #include <QLineEdit>
@@ -59,7 +59,7 @@ public:
             listWidget->addItem(new QListWidgetItem);
             const UMLEnum *e = type->asUMLEnum();
             UMLClassifierListItemList enumLiterals = e->getFilteredList(UMLObject::ot_EnumLiteral);
-            foreach (UMLClassifierListItem* enumLiteral, enumLiterals) {
+            for(UMLClassifierListItem* enumLiteral : enumLiterals) {
                 QListWidgetItem *item = new QListWidgetItem(enumLiteral->name());
                 listWidget->addItem(item);
             }
