@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -12,14 +12,16 @@
 #include "messagewidget.h"
 #include "floatingdashlinewidget.h"
 #include "objectwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlview.h"
 #include "umlwidget.h"
+#include "widget_utils.h"
 
 // qt includes
-#include <QMatrix> // need for inverseWorldMatrix.map
 #include <QScrollBar>
 
+DEBUG_REGISTER(ToolBarState)
+
 /**
  * Destroys this ToolBarState.
  * Frees m_pMouseEvent.
@@ -37,9 +39,9 @@ void ToolBarState::init()
 {
     if (m_pUMLScene->activeView())
         m_pUMLScene->activeView()->viewport()->setMouseTracking(false);
-    m_pMouseEvent = 0;
-    m_currentWidget = 0;
-    m_currentAssociation = 0;
+    m_pMouseEvent = nullptr;
+    m_currentWidget = nullptr;
+    m_currentAssociation = nullptr;
 
     connect(m_pUMLScene, SIGNAL(sigAssociationRemoved(AssociationWidget*)),
             this, SLOT(slotAssociationRemoved(AssociationWidget*)));
@@ -114,12 +116,15 @@ void ToolBarState::mouseRelease(QGraphicsSceneMouseEvent* ome)
     m_pUMLScene->activeView()->viewport()->setMouseTracking(false);
 
     if (currentWidget()) {
+        logDebug0("ToolBarState::mouseRelease calling mouseReleaseWidget");
         mouseReleaseWidget();
-        setCurrentWidget(0);
+        setCurrentWidget(nullptr);
     } else if (currentAssociation()) {
+        logDebug0("ToolBarState::mouseRelease calling mouseReleaseAssociation");
         mouseReleaseAssociation();
-        setCurrentAssociation(0);
+        setCurrentAssociation(nullptr);
     } else {
+        logDebug0("ToolBarState::mouseRelease calling mouseReleaseEmpty");
         mouseReleaseEmpty();
     }
 
@@ -150,11 +155,11 @@ void ToolBarState::mouseDoubleClick(QGraphicsSceneMouseEvent* ome)
     if (currentWidget) {
         setCurrentWidget(currentWidget);
         mouseDoubleClickWidget();
-        setCurrentWidget(0);
+        setCurrentWidget(nullptr);
     } else if (currentAssociation) {
         setCurrentAssociation(currentAssociation);
         mouseDoubleClickAssociation();
-        setCurrentAssociation(0);
+        setCurrentAssociation(nullptr);
     } else {
         mouseDoubleClickEmpty();
     }
@@ -200,10 +205,13 @@ void ToolBarState::mouseMove(QGraphicsSceneMouseEvent* ome)
 //             << "visibleArea [x, y, w, h] = [ " << visibleArea.x() << ", " << visibleArea.y() << ", " << visibleArea.width() << ", " << visibleArea.height() << "] / "
 //             << "maxArea [x, y, w, h] = [ " << maxArea.x() << ", " << maxArea.y() << ", " << maxArea.width() << ", " << maxArea.height() << "] / "
 //             << "delta right=" << dtr << ", bottom=" << dtb << ", top=" << dtt << ", left=" << dtl;
-    if (dtr < 30) { uDebug() << "translate RIGHT";  view->ensureVisible(vx, vy, 0.1 /*30-dtr*/, 0, 2, 2); }
+    if (dtr < 30) {
+        logDebug0("ToolBarState::mouseMove translate RIGHT");
+        view->ensureVisible(vx, vy, 0.1 /*30-dtr*/, 0, 2, 2);
+    }
     if (dtb < 30) {
         mouseCount++;
-        uDebug() << "translate BOTTOM " << mouseCount;
+        logDebug1("ToolBarState::mouseMove translate BOTTOM %1", mouseCount);
 //        view->ensureVisible(vx, vy, 0, 0.1 /*30-dtb*/, 2,  2);
         if (mouseCount > 30) {
             view->verticalScrollBar()->triggerAction(QAbstractSlider::SliderSingleStepAdd);
@@ -224,20 +232,20 @@ void ToolBarState::mouseMove(QGraphicsSceneMouseEvent* ome)
 void ToolBarState::slotAssociationRemoved(AssociationWidget* association)
 {
     if (association == currentAssociation()) {
-        setCurrentAssociation(0);
+        setCurrentAssociation(nullptr);
     }
 }
 
 /**
  * A widget was removed from the UMLScene.
  * If the widget removed was the current widget, the current widget is set
- * to 0.
+ * to nullptr.
  * It can be extended in subclasses if needed.
  */
 void ToolBarState::slotWidgetRemoved(UMLWidget* widget)
 {
     if (widget == currentWidget()) {
-        setCurrentWidget(0);
+        setCurrentWidget(nullptr);
     }
 }
 
@@ -252,7 +260,7 @@ void ToolBarState::slotWidgetRemoved(UMLWidget* widget)
 ToolBarState::ToolBarState(UMLScene *umlScene)
   : QObject(umlScene),
     m_pUMLScene(umlScene),
-    m_pMouseEvent(0)
+    m_pMouseEvent(nullptr)
 {
     init();
 }
@@ -358,6 +366,10 @@ void ToolBarState::mouseReleaseWidget()
  */
 void ToolBarState::mouseReleaseEmpty()
 {
+    if (m_currentWidget) {
+        logDebug0("ToolBarState::mouseReleaseEmpty : m_currentWidget is set => ensureNestedVisible");
+        Widget_Utils::ensureNestedVisible(m_currentWidget, m_pUMLScene->widgetList());
+    }
 }
 
 /**
@@ -510,12 +522,12 @@ void ToolBarState::setMouseEvent(QGraphicsSceneMouseEvent* ome, const QEvent::Ty
  */
 MessageWidget* ToolBarState::messageAt(const QPointF& pos)
 {
-    foreach (MessageWidget* message, m_pUMLScene->messageList()) {
+    for(MessageWidget* message : m_pUMLScene->messageList()) {
         if (message->isVisible() && message->onWidget(pos)) {
             return message;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -528,12 +540,12 @@ MessageWidget* ToolBarState::messageAt(const QPointF& pos)
  */
 AssociationWidget* ToolBarState::associationAt(const QPointF& pos)
 {
-    foreach (AssociationWidget* association, m_pUMLScene->associationList()) {
+    for(AssociationWidget* association : m_pUMLScene->associationList()) {
         if (association->onAssociation(pos)) {
             return association;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -545,9 +557,9 @@ AssociationWidget* ToolBarState::associationAt(const QPointF& pos)
  */
 FloatingDashLineWidget* ToolBarState::floatingLineAt(const QPointF& pos)
 {
-    FloatingDashLineWidget* floatingline = 0;
+    FloatingDashLineWidget *floatingline = nullptr;
 
-    foreach (UMLWidget* widget, m_pUMLScene->widgetList()) {
+    for(UMLWidget* widget : m_pUMLScene->widgetList()) {
         uIgnoreZeroPointer(widget);
         if (widget->isFloatingDashLineWidget()){
             if (widget->asFloatingDashLineWidget()->onLine(pos)) {
