@@ -7,14 +7,14 @@
 #include "enumwidget.h"
 
 // app includes
-#include "classifier.h"
-#include "classifierlistitem.h"
+#include "umlclassifier.h"
+#include "umlclassifierlistitem.h"
 #include "debug_utils.h"
-#include "enum.h"
-#include "enumliteral.h"
+#include "umlenum.h"
+#include "umlenumliteral.h"
 #include "listpopupmenu.h"
 #include "object_factory.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlclassifierlistitemlist.h"
 #include "umldoc.h"
 #include "umlscene.h"
